pynrc.nrc\_utils
================

.. automodule:: pynrc.nrc_utils

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      bias_dark_high_temp
      channel_select
      dark_ramp_80K
      do_charge_migration
      do_fft
      gen_unconvolved_point_source_image
      grism_background
      grism_background_com
      grism_background_image
      make_grism_slope
      nproc_use_convolve
      offset_bar
      pickoff_image
      pickoff_xy
      pix_noise
      place_grism_spec
      place_grismr_tso
      segment_pupil_opd
      var_ex_model
      zodi_euclid
      zodi_spec
   
   

   
   
   

   
   
   



